@@ -3,11 +3,10 @@ package MojoX::JSONRPC2::HTTP;
 use Mojo::Base -base;
 use Carp;
 
-use version; our $VERSION = qv('1.0.5');    # REMINDER: update Changes
+our $VERSION = 'v2.0.0';
 
-# REMINDER: update dependencies in Build.PL
 use Mojo::UserAgent;
-use JSON::RPC2::Client 0.2.0;   ## no critic (ProhibitVersionStrings)
+use JSON::RPC2::Client;
 use JSON::XS;
 use Scalar::Util qw(weaken);
 
@@ -117,6 +116,11 @@ __END__
 MojoX::JSONRPC2::HTTP - Client for JSON RPC 2.0 over HTTP
 
 
+=head1 VERSION
+
+This document describes MojoX::JSONRPC2::HTTP version v2.0.0
+
+
 =head1 SYNOPSIS
 
     use MojoX::JSONRPC2::HTTP;
@@ -258,7 +262,7 @@ undefined if RPC call was executes successfully.
 L<JSON::RPC2::Client>, L<Mojolicious>, L<Mojolicious::Plugin::JSONRPC2>.
 
 
-=head1 BUGS AND LIMITATIONS
+=head1 LIMITATIONS
 
 =over
 
@@ -268,69 +272,64 @@ Not supported because it is not implemented by L<JSON::RPC2::Client>.
 
 =back
 
-No bugs have been reported.
-
 
 =head1 SUPPORT
 
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=MojoX-JSONRPC2-HTTP>.
-I will be notified, and then you'll automatically be notified of progress
-on your bug as I make changes.
+=head2 Bugs / Feature Requests
 
-You can also look for information at:
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/powerman/perl-MojoX-JSONRPC2-HTTP/issues>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+Feel free to fork the repository and submit pull requests.
+
+L<https://github.com/powerman/perl-MojoX-JSONRPC2-HTTP>
+
+    git clone https://github.com/powerman/perl-MojoX-JSONRPC2-HTTP.git
+
+=head2 Resources
 
 =over
 
-=item * RT: CPAN's request tracker
+=item * MetaCPAN Search
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=MojoX-JSONRPC2-HTTP>
+L<https://metacpan.org/search?q=MojoX-JSONRPC2-HTTP>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/dist/MojoX-JSONRPC2-HTTP>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/MojoX-JSONRPC2-HTTP>
 
-=item * CPAN Ratings
+=item * CPAN Testers Matrix
 
-L<http://cpanratings.perl.org/d/MojoX-JSONRPC2-HTTP>
+L<http://matrix.cpantesters.org/?dist=MojoX-JSONRPC2-HTTP>
 
-=item * Search CPAN
+=item * CPANTS: A CPAN Testing Service (Kwalitee)
 
-L<http://search.cpan.org/dist/MojoX-JSONRPC2-HTTP/>
+L<http://cpants.cpanauthors.org/dist/MojoX-JSONRPC2-HTTP>
 
 =back
 
 
 =head1 AUTHOR
 
-Alex Efros  C<< <powerman@cpan.org> >>
+Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 Alex Efros <powerman@cpan.org>.
+This software is Copyright (c) 2014 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
-This program is distributed under the MIT (X11) License:
-L<http://www.opensource.org/licenses/mit-license.php>
+This is free software, licensed under:
 
-Permission is hereby granted, free of charge, to any person
-obtaining a copy of this software and associated documentation
-files (the "Software"), to deal in the Software without
-restriction, including without limitation the rights to use,
-copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following
-conditions:
+  The MIT (X11) License
 
-The above copyright notice and this permission notice shall be
-included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-OTHER DEALINGS IN THE SOFTWARE.
 
+=cut
